import React, { useContext } from 'react';

import { makeStyles } from '@material-ui/core/styles';
import { Container, Box, Paper, Button, TextField } from '@material-ui/core';

import { Formik } from 'formik';
import { SettingsContext } from 'lib/settings';

import { withRouter } from 'react-router-dom';

const useStyles = makeStyles(theme => ({
    root: {
        width: '100%',
        maxWidth: 360,
        backgroundColor: theme.palette.background.paper,
    },
    inline: {
        display: 'inline',
    },
    buttonBar: {
        paddingTop: theme.spacing(1),
        textAlign: "right"
    },
    button: {
        margin: theme.spacing(1),
    },

    form: {
        padding: theme.spacing(1)
    },

}));


export default withRouter((props) => {
    const classes = useStyles();
    const settings = useContext(SettingsContext);

    return (
        <Formik
            initialValues={{ username: settings.username || "", password: settings.password || "" }}
            validate={ values => {
                let errors = {};
                if (!values.username) {
                    errors.username = 'Required';
                }
                if (!values.password) {
                    errors.password = 'Required';
                }
                return errors;
            }}
            onSubmit={ async (values, { setSubmitting }) => {
                setSubmitting(true);
                try {
                    await settings.save(values);
                } catch (err) {
                    //TODO
                }
                setSubmitting(false);
            }}
            >

      {({
        values,
        errors,
        touched,
        handleChange,
        handleBlur,
        handleSubmit,
        isSubmitting,
      }) => (

        <Container maxWidth="md">
            <Box m={ 2 }>
                <Paper>
                    <form onSubmit={ handleSubmit }>
                        <Box className={ classes.form }>
                            <TextField
                                label="Username"
                                className={ classes.textField }
                                name="username"
                                value={ values.username }
                                onChange={ handleChange }
                                
                                fullWidth
                                margin="normal"

                                disabled={ isSubmitting }
                                helperText={ errors.username }
                                error={ !!errors.username }
                                />
                            <TextField
                                label="Password"
                                className={ classes.textField }
                                name="password"
                                type="password"
                                value={ values.password }
                                onChange={ handleChange }

                                fullWidth
                                margin="normal"

                                disabled={ isSubmitting }
                                helperText={ errors.email }
                                error={ !!errors.username }
                                />
                        </Box>

                        <Box className={ classes.buttonBar }>
                            <Button className={ classes.button } disabled={ isSubmitting } onClick={ () => props.history.push("/") }>
                                Cancel
                            </Button>
                            <Button type="submit" variant="contained" color="primary" className={classes.button} disabled={ isSubmitting }>
                                Ok
                            </Button>
                        </Box>
                    </form>
                </Paper>
            </Box>
        </Container>
        ) }
      </Formik>
    );
});